**********************************************
*************** DRMS ANALYSIS ****************
**********************************************

***** Analysis conducted by Payce Madden and Ayazhan Zhangalova
***** For the Desk Review and Market Study published by LASER PULSE, USAID, and Consilient Research
***** September 2023-February 2024

********* Household Survey
use "Household Survey.dta"

***** food security

bys respondent_type: tab city access1, row
bys respondent_type: tab city access3, row

gen access1_clean = access1
replace access1_clean = . if access1 == 99

reg access1_clean respondent_type, vce(cluster camp)

foreach i in 1 2 3 4 5 6{
	reg access1_clean respondent_type if city == `i'
}

****** dietary diversity

foreach i in 1 2 3 4 5 6 7 8 9 10 11{
	gen dd`i' = .
	replace dd`i' = 1 if food`i' >= 1 & food`i' <= 7
	replace dd`i' = 0 if food`i' == 9
}

egen diet_diver = rowtotal(dd1-dd10)
foreach i in 1 2 3 4 5 6 7 8 9 10 11{
	tab dd`i' respondent_type, col
}
bys respondent_type: sum diet_diver
bys city: sum diet_diver
bys city respondent_type: sum diet_diver

egen protein = rowtotal(dd5-dd8)
bys respondent_type: tab protein

foreach i in 5 6 7 8{
	gen food`i'_days = food`i'
	replace food`i'_days = 0 if food`i' == 9
	replace food`i'_days = . if food`i' == 99
}

egen protein_days = rowtotal(food5_days-food8_days)
bys respondent_type: sum protein_days

****** child dietary diversity

gen fg1 = 1 if children20_1 == 1 | children20_3 == 1
gen fg4 = 1 if children20_7 == 1 | children20_8 == 1 | children20_10 == 1
gen fg6 = 1 if children20_4 == 1 | children20_5 == 1
gen fg7 = 1 if children20_2 == 1 | children20_6 == 1
gen fg2 = children20_11
gen fg3 = children20_12
gen fg5 = children20_9

egen dd_child = rowtotal(fg1 fg2 fg3 fg4 fg5 fg6 fg7)
replace dd_child = . if dd_child == 0
tab dd_child

gen exbf = .
replace exbf = 1 if children9 == 1 | children10 == 1
foreach i in 11 12 13 14 15 16 17{
	replace exbf = 0 if children`i' == 1
}
replace exbf = . if children9 == 0
tab exbf respondent_type, col

replace dd_child = . if exbf == 1

tab dd_child

gen min_dd_child = .
replace min_dd_child = 0 if dd_child >= 0 & dd_child < 4
replace min_dd_child = 1 if dd_child >= 4 & dd_child <= 7

tab min_dd_child respondent_type, col
tab dd_child respondent_type, col

replace fg1 = 0 if children20_1 == 0 & children20_3 == 0
replace fg4 = 0 if children20_7 == 0 & children20_8 == 0 & children20_10 == 0
replace fg6 = 0 if children20_4 == 0 & children20_5 == 0
replace fg7 = 0 if children20_2 == 0 & children20_6 == 0

foreach i in 1 2 3 4 5 6 7{
	gen fg`i'_noebf = fg`i'
	replace fg`i'_noebf = . if exbf == 1
}

foreach i in 1 2 3 4 5 6 7{
	replace fg`i'_noebf = . if dd_child == 0 | dd_child == .
}

foreach i in 1 2 3 4 5 6 7{
	tab fg`i'_noebf respondent_type, col
}

foreach i in 11 12 13 14 15 16 17{
	tab children`i' if exbf == 0
}

gen fertile = .
replace fertile = 1 if children1 == 1 | children4 == 1
replace fertile = 0 if children1 == 0 & children4 == 0
replace fertile = . if age > 49 & age <= 99
tab fertile respondent_type, col


****** watsan
gen wat_prot = .
replace wat_prot = 1 if wash1 == 1 | wash1 == 2 | wash1 == 6
replace wat_prot = 0 if wash1 == 3 | wash1 == 5
replace wat_prot = 2 if wash1 == 7 | wash1 == 8 | wash1 == 9 | wash1 == 10

tab wat_prot respondent_type, col

// combining "other - cement slabs" into new answer option
replace wash8 = 20 if form_id == "d47db110-e5fb-42c6-adee-0c09c3f72dc7" | form_id == "f38a50b5-6a1c-4ab1-8401-3a2598068d6b" | form_id == "282c024e-de33-4aba-a934-88d3c808d6b8" | form_id == "a9b73cbd-7ff0-4753-a147-175989e6ac30" | form_id == "a602d2fa-ba2c-443a-bc5f-aabaec8025f5" | form_id == "44d00ba3-a23b-4725-b329-56b1d1a0b5ae" | form_id == "b6b6c239-474f-41b4-a998-662d2f287dea" | form_id == "fe1dd1cf-124b-482a-acb8-a24855eea5de" | form_id == "1e166928-26cd-4d5b-8639-cb5183a2e76a" | form_id == "fa49124b-46e3-43d0-a34a-406261c7027b" | form_id == "a071d683-e297-4e59-9bfb-03816d4f10ed" | form_id == "5ccb356d-ec60-42d7-bd39-55373d060804" | form_id == "bf40eb97-6da3-4c1f-a0b5-69cba6be266f" | form_id == "b86425b6-115b-4c84-8374-f7cfdbcd0a44" | form_id == "56a65016-471d-4c33-9562-185a655998f3" | form_id == "7fbffb55-d8c4-469e-b412-c13425293efb" | form_id == "ef5651ce-6875-4cb1-bf97-4a318d2ae846" | form_id == "6c9d15fb-97c9-4c00-876f-c850841bb3e6" | form_id == "d5053c5c-1452-4e46-9fde-e30fe964489f" | form_id == "1cb15604-731e-48bf-a98b-9c7700f8de2e" | form_id == "f61354e6-72df-4d7e-ade0-d40dd0e6ccd4" | form_id == "d475f5ce-33b8-43dd-a076-d8bb40b859e9" | form_id == "e7627634-cc92-4a00-a272-75e82647f2da" | form_id == "00ee1552-65ef-4992-af3b-01adea243d07" | form_id == "d6139360-972d-4a92-8a38-a82ff00e2107" | form_id == "83ded8b0-2d31-4827-b16f-4814fdeea7e3" | form_id == "700db264-8123-46f3-91fd-0da8ad06e351" | form_id == "a7acb47b-7ec2-4aae-a1db-a5c577749455" | form_id == "50743047-dad2-418f-877c-a5cc4e26e08f" | form_id == "d3bfee19-8b24-4c11-bee8-f01bb5c340d2" | form_id == "28a100b5-d66c-4ab8-92a9-162b28775e70" | form_id == "54c59559-10bd-444f-a333-39917da1ebdd" | form_id == "caa09eb2-6e94-472d-b69e-228311ca0ef1" | form_id == "6fc50b62-0742-48a0-97be-4b427070ca27" | form_id == "40898850-1cac-440c-8b70-600f3b0031f3" | form_id == "34932bec-c262-43fa-8c94-18aa99a6efd5" | form_id == "fe216182-10f2-40fb-aadb-31fa63c08d87" | form_id == "7160ec4f-05a0-435c-91f8-810c3038fb6d" | form_id == "63437efd-22d3-4227-a323-e554b8409fbf" | form_id == "e12ae52f-d1a4-4bb8-8eb4-b1aa9f6ec9ed" | form_id == "f484b0e6-6348-4ebf-8e22-e6a685e2e13f" | form_id == "93c388a8-80b5-4947-b2ac-c555425bfcf2" | form_id == "fe64da97-439b-4e6a-bd0a-1615cada4c5a" | form_id == "f477f92f-6564-4e28-a207-6c82c4f539b0" | form_id == "f1f0c294-af13-4e94-bfa3-fa21c282edfd" | form_id == "0fc4859a-4247-4f41-a059-faeb7d4a762d" | form_id == "86ec942a-a57c-46a5-a54b-7f70813bd799" | form_id == "c04c21fd-5f98-45ad-94c9-50fde44631a3" | form_id == "7578a107-496a-4e1a-a106-67d340cfac6e" | form_id == "4fd883a8-f1e5-44a2-a167-17d6086f6bb4" | form_id == "148a9007-dc07-40ed-9ecc-845043a2c74c" | form_id == "a1f27cba-d03c-47cb-953d-edb444194eb5" | form_id == "37aaca0f-13f8-4ce8-abad-a25c8688a3e2" | form_id == "a1e05634-0dc5-440e-a73b-865b07b7b340" | form_id == "51c6b14b-3f06-4dda-a05c-b9b0d7422580" | form_id == "476752f9-aee8-4dc0-9480-77b6331339ec" | form_id == "2a7ca426-d492-4ce3-9728-2ffd9d78a7d8" | form_id == "f5112803-a8ae-46b0-9b77-efd44bfdf551" | form_id == "26750686-9908-4182-bdd0-b66e9cf272f4" | form_id == "4e231606-8a7f-4410-9210-110cd4ba3c36" | form_id == "f6686fdb-bcac-434b-8106-b2c176d19482" | form_id == "8333c2f1-4b8d-4736-874b-21d20c8fb4aa" | form_id == "0a413687-ef6d-4ead-ac7f-1dca342cf50f" | form_id == "36297969-ed0a-4394-90ed-2b3bad79cfde" | form_id == "99501eb9-1c28-4ea8-b89e-d4fc5c8c635e" | form_id == "64b93ccb-96bd-4c72-b3de-1d6eae0735e2" | form_id == "8c6ca404-e826-434b-975e-7366d1b21518" | form_id == "630570b3-e36a-4481-954f-e9695271a8b8" | form_id == "a4b74518-5d20-4e0b-900f-fe6dccd6cb9d" | form_id == "0ccfd0aa-be84-4744-975f-c14db98e84d9" | form_id == "213b88b1-cab1-4158-a9be-bd7a0d67a4c5" | form_id == "cb26707b-f965-4e3a-affd-e4ef583c57fd" | form_id == "f4285cc0-f8bf-4501-b5f6-d0d8fdf7f45a" | form_id == "c2104839-ea7d-419a-8ea9-3922cc74560b"

gen san_prot = .
replace san_prot = 1 if wash8 == 1 | wash8 == 2 | wash8 == 3 | wash8 == 5 | wash8 == 8 | wash8 == 20
replace san_prot = 0 if wash8 == 4 | wash8 == 6 | wash8 == 7 | wash8 == 97

tab san_prot respondent_type, col

****** food availability

sum income_1 income_2 income_3 income_4 income_5 income_6 income_7 income_8 income_9 income_97 income_98 income_99 //Income sources
bysort respondent_type: sum income_1 income_2 income_3 income_4 income_5 income_6 income_7 income_8 income_9 income_97 income_98 income_99
bysort respondent_type city: sum income_1 income_2

tab agriculture1 //access to land
bysort respondent_type: tab agriculture1
bysort respondent_type city: tab agriculture1

sum agriculture8_b_1 agriculture8_b_2 agriculture8_b_3 agriculture8_b_4 agriculture8_b_5 agriculture8_b_6 agriculture8_b_7 agriculture8_b_8 agriculture8_b_97 agriculture8_b_99 //Crops Production problems
bysort respondent_type: sum agriculture8_b_1 agriculture8_b_2 agriculture8_b_3 agriculture8_b_4 agriculture8_b_5 agriculture8_b_6 agriculture8_b_7 agriculture8_b_8 agriculture8_b_97 agriculture8_b_99
bysort respondent_type city: sum agriculture8_b_1 agriculture8_b_2 agriculture8_b_3 agriculture8_b_4 agriculture8_b_5 agriculture8_b_6 agriculture8_b_7 agriculture8_b_8 agriculture8_b_97 agriculture8_b_99
 
tab agriculture4 //livestock ownership
bysort respondent_type: tab agriculture4
bysort respondent_type city: tab agriculture4

sum agriculture9_b_1 agriculture9_b_2 agriculture9_b_3 agriculture9_b_4 agriculture9_b_5 agriculture9_b_97 agriculture9_b_99 //Livestock Production problems
bysort respondent_type: sum agriculture9_b_1 agriculture9_b_2 agriculture9_b_3 agriculture9_b_4 agriculture9_b_5 agriculture9_b_97 agriculture9_b_99
bysort respondent_type city: sum agriculture9_b_1 agriculture9_b_2 agriculture9_b_3 agriculture9_b_4 agriculture9_b_5 agriculture9_b_97 agriculture9_b_99

****** Food access
///Household food consumption
foreach var in food1 food2 food3 food4 food5 food6 food7 food8 food9 food10 food11 food12 {
    gen `var'_new = .
	replace `var'_new = 1 if `var' !=9 & `var' !=99
	replace `var'_new = 0 if `var' == 9
}

bysort city: tab food1_new food2_new food3_new food4_new food5_new food6_new food7_new food8_new food9_new food10_new food11_new food12_new
sum food1_a_1-food1_a_99
sum food2_a_1-food2_a_99
sum food3_a_1-food3_a_99
sum food4_a_1-food4_a_99
sum food5_a_1-food5_a_99
sum food6_a_1-food6_a_99
sum food7_a_1-food7_a_99
sum food8_a_1-food8_a_99
sum food9_a_1-food9_a_99
sum food10_a_1-food10_a_99
sum food11_a_1-food11_a_99
sum food12_a_1-food12_a_99
tab food27 food28 food29 food30 food31 food32 food33 food34 food35 //Comparison between availability

sum food36 food37 food38 food39 food40 food41 food42 food43, detail //Monthly average purchase quantity
bysort city: sum  food36 food37 food38 food39 food40 food41 food42 food43, detail

bysort respondent_type: sum food1_a_3 food2_a_3 food3_a_3 food4_a_3 food5_a_3 food6_a_3 food7_a_3 food8_a_3 food9_a_3 food10_a_3 food11_a_3 food12_a_3 // Home production
bysort respondent_type: sum food1_a_7 food2_a_7 food3_a_7 food4_a_7 food5_a_7 food6_a_7 food7_a_7 food8_a_7 food9_a_7 food10_a_7 food11_a_7 food12_a_7 //Gift/loan 
sum food16_1 food16_2 food16_3 food16_4 food16_5 food16_6 food16_97 food16_98 food16_99 // Market access concerns

********* Vendor Survey
clear
use "Survey with Vendors.dta"

sum q10_1 q10_2 q10_3 q10_4 q10_5 q10_6 q10_97 q10_98 q10_99 ///Market actors
bysort city: sum q10_1 q10_2 q10_3 q10_4 q10_5 q10_6 q10_97 q10_98 q10_99

sum q16_a_1 q16_a_2 q16_a_3 q16_a_4 q16_a_5 q16_a_6 q16_a_7 q16_a_97 q16_a_98 q16_a_99 ///Government role
bysort city: sum q16_a_1 q16_a_2 q16_a_3 q16_a_4 q16_a_5 q16_a_6 q16_a_7 q16_a_97 q16_a_98 q16_a_99

sum q23_1 q23_2 q23_3 q23_4 q23_5 q23_6 q23_7 q23_8 q23_9 q23_10 q23_111 q23_97 q23_99 //Challenges related to expansion
bysort vendor_type: sum q23_1 q23_2 q23_3 q23_4 q23_5 q23_6 q23_7 q23_8 q23_9 q23_10 q23_111 q23_97 q23_99

bysort vendor_type: sum q13_a_1 q13_a_2 q13_a_3 q13_a_4 q13_a_5 q13_a_6 q13_a_97 q13_a_99 //Transportation

sum q7_a q7_b q7_c q7_d q7_e q7_f q7_g q7_h q7_i ///Harvest season
bysort city: sum q7_a q7_b q7_c q7_d q7_e q7_f q7_g q7_h q7_i, detail

sum q8_a q8_b q8_c q8_d q8_e q8_f q8_g q8_h q8_i ///Lean season
bysort city: sum q8_a q8_b q8_c q8_d q8_e q8_f q8_g q8_h q8_i, detail

////in USD
foreach var in q7_a q7_b q7_c q7_d q7_e q7_f q7_g q7_h q7_i q8_a q8_b q8_c q8_d q8_e  q8_f q8_g q8_h q8_i {
    gen `var'_new = `var'/24000
}

bysort city: sum q7_a_new q7_b_new q7_c_new q7_d_new q7_e_new q7_f_new q7_g_new q7_h_new q7_i_new, detail
bysort city: sum q8_a_new q8_b_new q8_c_new q8_d_new q8_e_new q8_f_new q8_g_new q8_h_new q8_i_new, detail

tab q18 //Price setting
bysort vendor_type: tab q18
sum q17_1 q17_2 q17_3 q17_4 q17_5 q17_6 q17_7 q17_8 q17_97 q17_99 //Price discovery

sum q19_1 q19_2 q19_3 q19_4 q19_5 q19_6 q19_7 q19_8 q19_97 q19_99 // Price reactivity
bysort vendor_type: sum q19_1 q19_2 q19_3 q19_4 q19_5 q19_6 q19_7 q19_8 q19_97 q19_99
tab q20
tab q14 // Storage
tab q14_a

sum q25_1 q25_2 q25_3 q25_4 q25_5 q25_6 q25_7 q25_8 q25_9 q25_10 q25_11 q25_97 q25_99 //Food aid
bysort city: sum q25_1 q25_2 q25_3 q25_4 q25_5 q25_6 q25_7 q25_8 q25_9 q25_10 q25_11 q25_97 q25_99 
sum q26_1-q26_99
bysort city: sum q26_1-q26_99
sum q27_1-q27_99
bysort city: sum q27_1-q27_99
tab q28

********* Market Observations
clear
use "Market Observations.dta"

foreach var of varlist sorghum sesame cowpea maize rice camel goat sheep fish{
	tab city `var', row
}

foreach var of varlist quality_sorghum quality_sesame quality_cowpea quality_maize quality_rice{
	tab city `var', row
}

foreach var of varlist price_sorghum price_sesame price_cowpea price_maize price_rice price_camel price_goat price_sheep price_fish{
	sum `var', d
	bys city: sum price_sorghum, d
}

foreach var of varlist quantity_sorghum quantity_sesame quantity_cowpea quantity_maize quantity_rice quantity_camel quantity_goat quantity_sheep quantity_fish{
	tab city `var', row
}
